=======
``veb``
=======

|PyPI| |Pythons| |CI|

.. |PyPI| image:: https://img.shields.io/pypi/v/veb.svg
  :alt: PyPI version
  :target: https://pypi.org/project/veb/

.. |Pythons| image:: https://img.shields.io/pypi/pyversions/veb.svg
  :alt: Supported Python versions
  :target: https://pypi.org/project/veb/

.. |CI| image:: https://github.com/Julian/veb/workflows/CI/badge.svg
  :alt: Build status
  :target: https://github.com/Julian/veb/actions?query=workflow%3ACI

Dynamically-allocated reduced-space van Emde Boas trees.
